"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
    RepeatedScalarFieldContainer as google___protobuf___internal___containers___RepeatedScalarFieldContainer,
)

from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    Iterable as typing___Iterable,
    NewType as typing___NewType,
    Optional as typing___Optional,
    Text as typing___Text,
    cast as typing___cast,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int


DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

MessageTypeValue = typing___NewType('MessageTypeValue', builtin___int)
type___MessageTypeValue = MessageTypeValue
MessageType: _MessageType
class _MessageType(google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[MessageTypeValue]):
    DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
    REPLY = typing___cast(MessageTypeValue, 0)
    INFO = typing___cast(MessageTypeValue, 1)
    ALERT = typing___cast(MessageTypeValue, 2)
REPLY = typing___cast(MessageTypeValue, 0)
INFO = typing___cast(MessageTypeValue, 1)
ALERT = typing___cast(MessageTypeValue, 2)

ErrorsValue = typing___NewType('ErrorsValue', builtin___int)
type___ErrorsValue = ErrorsValue
Errors: _Errors
class _Errors(google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[ErrorsValue]):
    DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
    REQUEST_TIMEOUT = typing___cast(ErrorsValue, 0)
    CONNECTION_CLOSED = typing___cast(ErrorsValue, 1)
    INVALID_ARGUMENT = typing___cast(ErrorsValue, 2)
    OUT_OF_REQUEST_IDS = typing___cast(ErrorsValue, 3)
    INVALID_PACKET = typing___cast(ErrorsValue, 4)
    CONNECTION_FAILED = typing___cast(ErrorsValue, 5)
    UNKNOWN_REQUEST = typing___cast(ErrorsValue, 6)
    COMMAND_FAILED = typing___cast(ErrorsValue, 7)
    DEVICE_DB_FAILED = typing___cast(ErrorsValue, 8)
    INVALID_DATA = typing___cast(ErrorsValue, 9)
    DEVICE_NOT_IDENTIFIED = typing___cast(ErrorsValue, 10)
    CONVERSION_FAILED = typing___cast(ErrorsValue, 11)
    DEVICE_ADDRESS_CONFLICT = typing___cast(ErrorsValue, 12)
    NO_DEVICE_FOUND = typing___cast(ErrorsValue, 13)
    MOVEMENT_INTERRUPTED = typing___cast(ErrorsValue, 14)
    MOVEMENT_FAILED = typing___cast(ErrorsValue, 15)
    IO_FAILED = typing___cast(ErrorsValue, 16)
    INVALID_RESPONSE = typing___cast(ErrorsValue, 17)
    NOT_SUPPORTED = typing___cast(ErrorsValue, 18)
    DEVICE_FAILED = typing___cast(ErrorsValue, 19)
    OS_FAILED = typing___cast(ErrorsValue, 20)
    INTERNAL_ERROR = typing___cast(ErrorsValue, 22)
    BINARY_COMMAND_FAILED = typing___cast(ErrorsValue, 24)
    COMMAND_PREEMPTED = typing___cast(ErrorsValue, 25)
    LOCKSTEP_NOT_ENABLED = typing___cast(ErrorsValue, 26)
    LOCKSTEP_ENABLED = typing___cast(ErrorsValue, 27)
    IO_CHANNEL_OUT_OF_RANGE = typing___cast(ErrorsValue, 28)
    SETTING_NOT_FOUND = typing___cast(ErrorsValue, 29)
    STREAM_MODE = typing___cast(ErrorsValue, 30)
    STREAM_EXECUTION = typing___cast(ErrorsValue, 31)
    STREAM_MOVEMENT_FAILED = typing___cast(ErrorsValue, 32)
    STREAM_SETUP_FAILED = typing___cast(ErrorsValue, 33)
    DEVICE_BUSY = typing___cast(ErrorsValue, 34)
    STREAM_MOVEMENT_INTERRUPTED = typing___cast(ErrorsValue, 35)
    INVALID_PARK_STATE = typing___cast(ErrorsValue, 36)
    SERIAL_PORT_BUSY = typing___cast(ErrorsValue, 37)
REQUEST_TIMEOUT = typing___cast(ErrorsValue, 0)
CONNECTION_CLOSED = typing___cast(ErrorsValue, 1)
INVALID_ARGUMENT = typing___cast(ErrorsValue, 2)
OUT_OF_REQUEST_IDS = typing___cast(ErrorsValue, 3)
INVALID_PACKET = typing___cast(ErrorsValue, 4)
CONNECTION_FAILED = typing___cast(ErrorsValue, 5)
UNKNOWN_REQUEST = typing___cast(ErrorsValue, 6)
COMMAND_FAILED = typing___cast(ErrorsValue, 7)
DEVICE_DB_FAILED = typing___cast(ErrorsValue, 8)
INVALID_DATA = typing___cast(ErrorsValue, 9)
DEVICE_NOT_IDENTIFIED = typing___cast(ErrorsValue, 10)
CONVERSION_FAILED = typing___cast(ErrorsValue, 11)
DEVICE_ADDRESS_CONFLICT = typing___cast(ErrorsValue, 12)
NO_DEVICE_FOUND = typing___cast(ErrorsValue, 13)
MOVEMENT_INTERRUPTED = typing___cast(ErrorsValue, 14)
MOVEMENT_FAILED = typing___cast(ErrorsValue, 15)
IO_FAILED = typing___cast(ErrorsValue, 16)
INVALID_RESPONSE = typing___cast(ErrorsValue, 17)
NOT_SUPPORTED = typing___cast(ErrorsValue, 18)
DEVICE_FAILED = typing___cast(ErrorsValue, 19)
OS_FAILED = typing___cast(ErrorsValue, 20)
INTERNAL_ERROR = typing___cast(ErrorsValue, 22)
BINARY_COMMAND_FAILED = typing___cast(ErrorsValue, 24)
COMMAND_PREEMPTED = typing___cast(ErrorsValue, 25)
LOCKSTEP_NOT_ENABLED = typing___cast(ErrorsValue, 26)
LOCKSTEP_ENABLED = typing___cast(ErrorsValue, 27)
IO_CHANNEL_OUT_OF_RANGE = typing___cast(ErrorsValue, 28)
SETTING_NOT_FOUND = typing___cast(ErrorsValue, 29)
STREAM_MODE = typing___cast(ErrorsValue, 30)
STREAM_EXECUTION = typing___cast(ErrorsValue, 31)
STREAM_MOVEMENT_FAILED = typing___cast(ErrorsValue, 32)
STREAM_SETUP_FAILED = typing___cast(ErrorsValue, 33)
DEVICE_BUSY = typing___cast(ErrorsValue, 34)
STREAM_MOVEMENT_INTERRUPTED = typing___cast(ErrorsValue, 35)
INVALID_PARK_STATE = typing___cast(ErrorsValue, 36)
SERIAL_PORT_BUSY = typing___cast(ErrorsValue, 37)

InterfaceTypeValue = typing___NewType('InterfaceTypeValue', builtin___int)
type___InterfaceTypeValue = InterfaceTypeValue
InterfaceType: _InterfaceType
class _InterfaceType(google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[InterfaceTypeValue]):
    DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
    SERIAL_PORT = typing___cast(InterfaceTypeValue, 0)
    TCP = typing___cast(InterfaceTypeValue, 1)
SERIAL_PORT = typing___cast(InterfaceTypeValue, 0)
TCP = typing___cast(InterfaceTypeValue, 1)

class Request(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    request: typing___Text = ...

    def __init__(self,
        *,
        request : typing___Optional[typing___Text] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"request",b"request"]) -> None: ...
type___Request = Request

class Response(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ResponseTypeValue = typing___NewType('ResponseTypeValue', builtin___int)
    type___ResponseTypeValue = ResponseTypeValue
    ResponseType: _ResponseType
    class _ResponseType(google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[Response.ResponseTypeValue]):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        OK = typing___cast(Response.ResponseTypeValue, 0)
        ERROR = typing___cast(Response.ResponseTypeValue, 1)
    OK = typing___cast(Response.ResponseTypeValue, 0)
    ERROR = typing___cast(Response.ResponseTypeValue, 1)

    response: type___Response.ResponseTypeValue = ...
    error_type: type___ErrorsValue = ...
    error_message: typing___Text = ...

    def __init__(self,
        *,
        response : typing___Optional[type___Response.ResponseTypeValue] = None,
        error_type : typing___Optional[type___ErrorsValue] = None,
        error_message : typing___Optional[typing___Text] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"error_message",b"error_message",u"error_type",b"error_type",u"response",b"response"]) -> None: ...
type___Response = Response

class Event(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    event: typing___Text = ...

    def __init__(self,
        *,
        event : typing___Optional[typing___Text] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"event",b"event"]) -> None: ...
type___Event = Event

class EmptyRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    def __init__(self,
        ) -> None: ...
type___EmptyRequest = EmptyRequest

class AxisIdentity(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AxisTypeValue = typing___NewType('AxisTypeValue', builtin___int)
    type___AxisTypeValue = AxisTypeValue
    AxisType: _AxisType
    class _AxisType(google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[AxisIdentity.AxisTypeValue]):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNKNOWN = typing___cast(AxisIdentity.AxisTypeValue, 0)
        LINEAR = typing___cast(AxisIdentity.AxisTypeValue, 1)
        ROTARY = typing___cast(AxisIdentity.AxisTypeValue, 2)
    UNKNOWN = typing___cast(AxisIdentity.AxisTypeValue, 0)
    LINEAR = typing___cast(AxisIdentity.AxisTypeValue, 1)
    ROTARY = typing___cast(AxisIdentity.AxisTypeValue, 2)

    is_peripheral: builtin___bool = ...
    peripheral_id: builtin___int = ...
    peripheral_name: typing___Text = ...
    axis_type: type___AxisIdentity.AxisTypeValue = ...

    def __init__(self,
        *,
        is_peripheral : typing___Optional[builtin___bool] = None,
        peripheral_id : typing___Optional[builtin___int] = None,
        peripheral_name : typing___Optional[typing___Text] = None,
        axis_type : typing___Optional[type___AxisIdentity.AxisTypeValue] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"axis_type",b"axis_type",u"is_peripheral",b"is_peripheral",u"peripheral_id",b"peripheral_id",u"peripheral_name",b"peripheral_name"]) -> None: ...
type___AxisIdentity = AxisIdentity

class DeviceIdentity(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    device_id: builtin___int = ...
    serial_number: builtin___int = ...
    name: typing___Text = ...
    axis_count: builtin___int = ...

    @property
    def firmware_version(self) -> type___FirmwareVersion: ...

    def __init__(self,
        *,
        device_id : typing___Optional[builtin___int] = None,
        serial_number : typing___Optional[builtin___int] = None,
        name : typing___Optional[typing___Text] = None,
        axis_count : typing___Optional[builtin___int] = None,
        firmware_version : typing___Optional[type___FirmwareVersion] = None,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions___Literal[u"firmware_version",b"firmware_version"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"axis_count",b"axis_count",u"device_id",b"device_id",u"firmware_version",b"firmware_version",u"name",b"name",u"serial_number",b"serial_number"]) -> None: ...
type___DeviceIdentity = DeviceIdentity

class FirmwareVersion(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    major: builtin___int = ...
    minor: builtin___int = ...
    build: builtin___int = ...

    def __init__(self,
        *,
        major : typing___Optional[builtin___int] = None,
        minor : typing___Optional[builtin___int] = None,
        build : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"build",b"build",u"major",b"major",u"minor",b"minor"]) -> None: ...
type___FirmwareVersion = FirmwareVersion

class DeviceIOInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    number_analog_outputs: builtin___int = ...
    number_analog_inputs: builtin___int = ...
    number_digital_outputs: builtin___int = ...
    number_digital_inputs: builtin___int = ...

    def __init__(self,
        *,
        number_analog_outputs : typing___Optional[builtin___int] = None,
        number_analog_inputs : typing___Optional[builtin___int] = None,
        number_digital_outputs : typing___Optional[builtin___int] = None,
        number_digital_inputs : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"number_analog_inputs",b"number_analog_inputs",u"number_analog_outputs",b"number_analog_outputs",u"number_digital_inputs",b"number_digital_inputs",u"number_digital_outputs",b"number_digital_outputs"]) -> None: ...
type___DeviceIOInfo = DeviceIOInfo

class Measurement(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    value: builtin___float = ...
    unit: typing___Text = ...

    def __init__(self,
        *,
        value : typing___Optional[builtin___float] = None,
        unit : typing___Optional[typing___Text] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"unit",b"unit",u"value",b"value"]) -> None: ...
type___Measurement = Measurement

class StreamAxisDefinition(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    axis_number: builtin___int = ...
    axis_type: builtin___int = ...

    def __init__(self,
        *,
        axis_number : typing___Optional[builtin___int] = None,
        axis_type : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"axis_number",b"axis_number",u"axis_type",b"axis_type"]) -> None: ...
type___StreamAxisDefinition = StreamAxisDefinition

class InvalidPacketExceptionData(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    packet: typing___Text = ...
    reason: typing___Text = ...

    def __init__(self,
        *,
        packet : typing___Optional[typing___Text] = None,
        reason : typing___Optional[typing___Text] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"packet",b"packet",u"reason",b"reason"]) -> None: ...
type___InvalidPacketExceptionData = InvalidPacketExceptionData

class DeviceAddressConflictExceptionData(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    device_addresses: google___protobuf___internal___containers___RepeatedScalarFieldContainer[builtin___int] = ...

    def __init__(self,
        *,
        device_addresses : typing___Optional[typing___Iterable[builtin___int]] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device_addresses",b"device_addresses"]) -> None: ...
type___DeviceAddressConflictExceptionData = DeviceAddressConflictExceptionData

class MovementInterruptedExceptionData(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    warnings: google___protobuf___internal___containers___RepeatedScalarFieldContainer[typing___Text] = ...
    reason: typing___Text = ...

    def __init__(self,
        *,
        warnings : typing___Optional[typing___Iterable[typing___Text]] = None,
        reason : typing___Optional[typing___Text] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"reason",b"reason",u"warnings",b"warnings"]) -> None: ...
type___MovementInterruptedExceptionData = MovementInterruptedExceptionData

class StreamMovementInterruptedExceptionData(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    warnings: google___protobuf___internal___containers___RepeatedScalarFieldContainer[typing___Text] = ...
    reason: typing___Text = ...

    def __init__(self,
        *,
        warnings : typing___Optional[typing___Iterable[typing___Text]] = None,
        reason : typing___Optional[typing___Text] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"reason",b"reason",u"warnings",b"warnings"]) -> None: ...
type___StreamMovementInterruptedExceptionData = StreamMovementInterruptedExceptionData

class MovementFailedExceptionData(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    warnings: google___protobuf___internal___containers___RepeatedScalarFieldContainer[typing___Text] = ...
    reason: typing___Text = ...

    def __init__(self,
        *,
        warnings : typing___Optional[typing___Iterable[typing___Text]] = None,
        reason : typing___Optional[typing___Text] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"reason",b"reason",u"warnings",b"warnings"]) -> None: ...
type___MovementFailedExceptionData = MovementFailedExceptionData

class StreamMovementFailedExceptionData(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    warnings: google___protobuf___internal___containers___RepeatedScalarFieldContainer[typing___Text] = ...
    reason: typing___Text = ...

    def __init__(self,
        *,
        warnings : typing___Optional[typing___Iterable[typing___Text]] = None,
        reason : typing___Optional[typing___Text] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"reason",b"reason",u"warnings",b"warnings"]) -> None: ...
type___StreamMovementFailedExceptionData = StreamMovementFailedExceptionData

class StreamExecutionExceptionData(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    error_flag: typing___Text = ...
    reason: typing___Text = ...

    def __init__(self,
        *,
        error_flag : typing___Optional[typing___Text] = None,
        reason : typing___Optional[typing___Text] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"error_flag",b"error_flag",u"reason",b"reason"]) -> None: ...
type___StreamExecutionExceptionData = StreamExecutionExceptionData

class InvalidResponseExceptionData(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    response: typing___Text = ...

    def __init__(self,
        *,
        response : typing___Optional[typing___Text] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"response",b"response"]) -> None: ...
type___InvalidResponseExceptionData = InvalidResponseExceptionData

class CommandFailedExceptionData(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    response_data: typing___Text = ...
    reply_flag: typing___Text = ...
    status: typing___Text = ...
    warning_flag: typing___Text = ...

    def __init__(self,
        *,
        response_data : typing___Optional[typing___Text] = None,
        reply_flag : typing___Optional[typing___Text] = None,
        status : typing___Optional[typing___Text] = None,
        warning_flag : typing___Optional[typing___Text] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"reply_flag",b"reply_flag",u"response_data",b"response_data",u"status",b"status",u"warning_flag",b"warning_flag"]) -> None: ...
type___CommandFailedExceptionData = CommandFailedExceptionData

class BinaryCommandFailedExceptionData(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    response_data: builtin___int = ...

    def __init__(self,
        *,
        response_data : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"response_data",b"response_data"]) -> None: ...
type___BinaryCommandFailedExceptionData = BinaryCommandFailedExceptionData

class TestRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    return_error: builtin___bool = ...
    data_ping: typing___Text = ...
    return_error_with_data: builtin___bool = ...

    def __init__(self,
        *,
        return_error : typing___Optional[builtin___bool] = None,
        data_ping : typing___Optional[typing___Text] = None,
        return_error_with_data : typing___Optional[builtin___bool] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"data_ping",b"data_ping",u"return_error",b"return_error",u"return_error_with_data",b"return_error_with_data"]) -> None: ...
type___TestRequest = TestRequest

class TestResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    data_pong: typing___Text = ...

    def __init__(self,
        *,
        data_pong : typing___Optional[typing___Text] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"data_pong",b"data_pong"]) -> None: ...
type___TestResponse = TestResponse

class TestResponseLong(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    data_pong: google___protobuf___internal___containers___RepeatedScalarFieldContainer[typing___Text] = ...

    def __init__(self,
        *,
        data_pong : typing___Optional[typing___Iterable[typing___Text]] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"data_pong",b"data_pong"]) -> None: ...
type___TestResponseLong = TestResponseLong

class TestEvent(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    data: typing___Text = ...

    def __init__(self,
        *,
        data : typing___Optional[typing___Text] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"data",b"data"]) -> None: ...
type___TestEvent = TestEvent

class ToolsListSerialPortsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ports: google___protobuf___internal___containers___RepeatedScalarFieldContainer[typing___Text] = ...

    def __init__(self,
        *,
        ports : typing___Optional[typing___Iterable[typing___Text]] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"ports",b"ports"]) -> None: ...
type___ToolsListSerialPortsResponse = ToolsListSerialPortsResponse

class SetDeviceDbSourceRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    source_type: builtin___int = ...
    url_or_file_path: typing___Text = ...

    def __init__(self,
        *,
        source_type : typing___Optional[builtin___int] = None,
        url_or_file_path : typing___Optional[typing___Text] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"source_type",b"source_type",u"url_or_file_path",b"url_or_file_path"]) -> None: ...
type___SetDeviceDbSourceRequest = SetDeviceDbSourceRequest

class ToggleDeviceDbStoreRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    toggle_on: builtin___bool = ...
    store_location: typing___Text = ...

    def __init__(self,
        *,
        toggle_on : typing___Optional[builtin___bool] = None,
        store_location : typing___Optional[typing___Text] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"store_location",b"store_location",u"toggle_on",b"toggle_on"]) -> None: ...
type___ToggleDeviceDbStoreRequest = ToggleDeviceDbStoreRequest

class OpenInterfaceRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_type: type___InterfaceTypeValue = ...
    port_name: typing___Text = ...
    baud_rate: builtin___int = ...
    host_name: typing___Text = ...
    port: builtin___int = ...

    def __init__(self,
        *,
        interface_type : typing___Optional[type___InterfaceTypeValue] = None,
        port_name : typing___Optional[typing___Text] = None,
        baud_rate : typing___Optional[builtin___int] = None,
        host_name : typing___Optional[typing___Text] = None,
        port : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"baud_rate",b"baud_rate",u"host_name",b"host_name",u"interface_type",b"interface_type",u"port",b"port",u"port_name",b"port_name"]) -> None: ...
type___OpenInterfaceRequest = OpenInterfaceRequest

class OpenInterfaceResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"interface_id",b"interface_id"]) -> None: ...
type___OpenInterfaceResponse = OpenInterfaceResponse

class CloseInterfaceRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"interface_id",b"interface_id"]) -> None: ...
type___CloseInterfaceRequest = CloseInterfaceRequest

class EmptyInterfaceRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"interface_id",b"interface_id"]) -> None: ...
type___EmptyInterfaceRequest = EmptyInterfaceRequest

class GetInterfaceTimeoutResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    value: builtin___int = ...

    def __init__(self,
        *,
        value : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"value",b"value"]) -> None: ...
type___GetInterfaceTimeoutResponse = GetInterfaceTimeoutResponse

class SetInterfaceTimeoutRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    timeout: builtin___int = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        timeout : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"interface_id",b"interface_id",u"timeout",b"timeout"]) -> None: ...
type___SetInterfaceTimeoutRequest = SetInterfaceTimeoutRequest

class GetInterfaceChecksumEnabledResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    value: builtin___bool = ...

    def __init__(self,
        *,
        value : typing___Optional[builtin___bool] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"value",b"value"]) -> None: ...
type___GetInterfaceChecksumEnabledResponse = GetInterfaceChecksumEnabledResponse

class SetInterfaceChecksumEnabledRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    is_enabled: builtin___bool = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        is_enabled : typing___Optional[builtin___bool] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"interface_id",b"interface_id",u"is_enabled",b"is_enabled"]) -> None: ...
type___SetInterfaceChecksumEnabledRequest = SetInterfaceChecksumEnabledRequest

class ToStringRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    axis: builtin___int = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        axis : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"axis",b"axis",u"device",b"device",u"interface_id",b"interface_id"]) -> None: ...
type___ToStringRequest = ToStringRequest

class ToStringResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    to_str: typing___Text = ...

    def __init__(self,
        *,
        to_str : typing___Optional[typing___Text] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"to_str",b"to_str"]) -> None: ...
type___ToStringResponse = ToStringResponse

class GenericCommandRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    axis: builtin___int = ...
    command: typing___Text = ...
    check_errors: builtin___bool = ...
    timeout: builtin___int = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        axis : typing___Optional[builtin___int] = None,
        command : typing___Optional[typing___Text] = None,
        check_errors : typing___Optional[builtin___bool] = None,
        timeout : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"axis",b"axis",u"check_errors",b"check_errors",u"command",b"command",u"device",b"device",u"interface_id",b"interface_id",u"timeout",b"timeout"]) -> None: ...
type___GenericCommandRequest = GenericCommandRequest

class GenericCommandResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    device_address: builtin___int = ...
    axis_number: builtin___int = ...
    reply_flag: typing___Text = ...
    status: typing___Text = ...
    warning_flag: typing___Text = ...
    data: typing___Text = ...
    message_type: type___MessageTypeValue = ...

    def __init__(self,
        *,
        device_address : typing___Optional[builtin___int] = None,
        axis_number : typing___Optional[builtin___int] = None,
        reply_flag : typing___Optional[typing___Text] = None,
        status : typing___Optional[typing___Text] = None,
        warning_flag : typing___Optional[typing___Text] = None,
        data : typing___Optional[typing___Text] = None,
        message_type : typing___Optional[type___MessageTypeValue] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"axis_number",b"axis_number",u"data",b"data",u"device_address",b"device_address",u"message_type",b"message_type",u"reply_flag",b"reply_flag",u"status",b"status",u"warning_flag",b"warning_flag"]) -> None: ...
type___GenericCommandResponse = GenericCommandResponse

class GenericCommandResponseCollection(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def responses(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___GenericCommandResponse]: ...

    def __init__(self,
        *,
        responses : typing___Optional[typing___Iterable[type___GenericCommandResponse]] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"responses",b"responses"]) -> None: ...
type___GenericCommandResponseCollection = GenericCommandResponseCollection

class UnknownResponseEvent(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device_address: builtin___int = ...
    axis_number: builtin___int = ...
    reply_flag: typing___Text = ...
    status: typing___Text = ...
    warning_flag: typing___Text = ...
    data: typing___Text = ...
    message_type: type___MessageTypeValue = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device_address : typing___Optional[builtin___int] = None,
        axis_number : typing___Optional[builtin___int] = None,
        reply_flag : typing___Optional[typing___Text] = None,
        status : typing___Optional[typing___Text] = None,
        warning_flag : typing___Optional[typing___Text] = None,
        data : typing___Optional[typing___Text] = None,
        message_type : typing___Optional[type___MessageTypeValue] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"axis_number",b"axis_number",u"data",b"data",u"device_address",b"device_address",u"interface_id",b"interface_id",u"message_type",b"message_type",u"reply_flag",b"reply_flag",u"status",b"status",u"warning_flag",b"warning_flag"]) -> None: ...
type___UnknownResponseEvent = UnknownResponseEvent

class AlertEvent(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device_address: builtin___int = ...
    axis_number: builtin___int = ...
    status: typing___Text = ...
    warning_flag: typing___Text = ...
    data: typing___Text = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device_address : typing___Optional[builtin___int] = None,
        axis_number : typing___Optional[builtin___int] = None,
        status : typing___Optional[typing___Text] = None,
        warning_flag : typing___Optional[typing___Text] = None,
        data : typing___Optional[typing___Text] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"axis_number",b"axis_number",u"data",b"data",u"device_address",b"device_address",u"interface_id",b"interface_id",u"status",b"status",u"warning_flag",b"warning_flag"]) -> None: ...
type___AlertEvent = AlertEvent

class DisconnectedEvent(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    error_type: type___ErrorsValue = ...
    error_message: typing___Text = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        error_type : typing___Optional[type___ErrorsValue] = None,
        error_message : typing___Optional[typing___Text] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"error_message",b"error_message",u"error_type",b"error_type",u"interface_id",b"interface_id"]) -> None: ...
type___DisconnectedEvent = DisconnectedEvent

class DeviceRenumberRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    first_address: builtin___int = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        first_address : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"first_address",b"first_address",u"interface_id",b"interface_id"]) -> None: ...
type___DeviceRenumberRequest = DeviceRenumberRequest

class DeviceRenumberResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    number_devices: builtin___int = ...

    def __init__(self,
        *,
        number_devices : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"number_devices",b"number_devices"]) -> None: ...
type___DeviceRenumberResponse = DeviceRenumberResponse

class DeviceDetectRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    identify_devices: builtin___bool = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        identify_devices : typing___Optional[builtin___bool] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"identify_devices",b"identify_devices",u"interface_id",b"interface_id"]) -> None: ...
type___DeviceDetectRequest = DeviceDetectRequest

class DeviceDetectResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    devices: google___protobuf___internal___containers___RepeatedScalarFieldContainer[builtin___int] = ...

    def __init__(self,
        *,
        devices : typing___Optional[typing___Iterable[builtin___int]] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"devices",b"devices"]) -> None: ...
type___DeviceDetectResponse = DeviceDetectResponse

class DeviceHomeRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    axis: builtin___int = ...
    wait_until_idle: builtin___bool = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        axis : typing___Optional[builtin___int] = None,
        wait_until_idle : typing___Optional[builtin___bool] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"axis",b"axis",u"device",b"device",u"interface_id",b"interface_id",u"wait_until_idle",b"wait_until_idle"]) -> None: ...
type___DeviceHomeRequest = DeviceHomeRequest

class DeviceWaitUntilIdleRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    axis: builtin___int = ...
    throw_error_on_fault: builtin___bool = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        axis : typing___Optional[builtin___int] = None,
        throw_error_on_fault : typing___Optional[builtin___bool] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"axis",b"axis",u"device",b"device",u"interface_id",b"interface_id",u"throw_error_on_fault",b"throw_error_on_fault"]) -> None: ...
type___DeviceWaitUntilIdleRequest = DeviceWaitUntilIdleRequest

class DeviceMoveRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    MoveTypeValue = typing___NewType('MoveTypeValue', builtin___int)
    type___MoveTypeValue = MoveTypeValue
    MoveType: _MoveType
    class _MoveType(google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[DeviceMoveRequest.MoveTypeValue]):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        ABS = typing___cast(DeviceMoveRequest.MoveTypeValue, 0)
        REL = typing___cast(DeviceMoveRequest.MoveTypeValue, 1)
        VEL = typing___cast(DeviceMoveRequest.MoveTypeValue, 2)
        MAX = typing___cast(DeviceMoveRequest.MoveTypeValue, 3)
        MIN = typing___cast(DeviceMoveRequest.MoveTypeValue, 4)
    ABS = typing___cast(DeviceMoveRequest.MoveTypeValue, 0)
    REL = typing___cast(DeviceMoveRequest.MoveTypeValue, 1)
    VEL = typing___cast(DeviceMoveRequest.MoveTypeValue, 2)
    MAX = typing___cast(DeviceMoveRequest.MoveTypeValue, 3)
    MIN = typing___cast(DeviceMoveRequest.MoveTypeValue, 4)

    interface_id: builtin___int = ...
    device: builtin___int = ...
    axis: builtin___int = ...
    wait_until_idle: builtin___bool = ...
    type: type___DeviceMoveRequest.MoveTypeValue = ...
    arg: builtin___float = ...
    unit: typing___Text = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        axis : typing___Optional[builtin___int] = None,
        wait_until_idle : typing___Optional[builtin___bool] = None,
        type : typing___Optional[type___DeviceMoveRequest.MoveTypeValue] = None,
        arg : typing___Optional[builtin___float] = None,
        unit : typing___Optional[typing___Text] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"arg",b"arg",u"axis",b"axis",u"device",b"device",u"interface_id",b"interface_id",u"type",b"type",u"unit",b"unit",u"wait_until_idle",b"wait_until_idle"]) -> None: ...
type___DeviceMoveRequest = DeviceMoveRequest

class DeviceStopRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    axis: builtin___int = ...
    wait_until_idle: builtin___bool = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        axis : typing___Optional[builtin___int] = None,
        wait_until_idle : typing___Optional[builtin___bool] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"axis",b"axis",u"device",b"device",u"interface_id",b"interface_id",u"wait_until_idle",b"wait_until_idle"]) -> None: ...
type___DeviceStopRequest = DeviceStopRequest

class DeviceIdentifyRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device",b"device",u"interface_id",b"interface_id"]) -> None: ...
type___DeviceIdentifyRequest = DeviceIdentifyRequest

class DeviceOnAllRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    wait_until_idle: builtin___bool = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        wait_until_idle : typing___Optional[builtin___bool] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"interface_id",b"interface_id",u"wait_until_idle",b"wait_until_idle"]) -> None: ...
type___DeviceOnAllRequest = DeviceOnAllRequest

class DeviceOnAllResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    device_addresses: google___protobuf___internal___containers___RepeatedScalarFieldContainer[builtin___int] = ...

    def __init__(self,
        *,
        device_addresses : typing___Optional[typing___Iterable[builtin___int]] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device_addresses",b"device_addresses"]) -> None: ...
type___DeviceOnAllResponse = DeviceOnAllResponse

class DeviceGetIdentityRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device",b"device",u"interface_id",b"interface_id"]) -> None: ...
type___DeviceGetIdentityRequest = DeviceGetIdentityRequest

class DeviceGetIdentityResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def identity(self) -> type___DeviceIdentity: ...

    def __init__(self,
        *,
        identity : typing___Optional[type___DeviceIdentity] = None,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions___Literal[u"identity",b"identity"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"identity",b"identity"]) -> None: ...
type___DeviceGetIdentityResponse = DeviceGetIdentityResponse

class DeviceGetIsIdentifiedRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device",b"device",u"interface_id",b"interface_id"]) -> None: ...
type___DeviceGetIsIdentifiedRequest = DeviceGetIsIdentifiedRequest

class DeviceGetIsIdentifiedResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    is_identified: builtin___bool = ...

    def __init__(self,
        *,
        is_identified : typing___Optional[builtin___bool] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"is_identified",b"is_identified"]) -> None: ...
type___DeviceGetIsIdentifiedResponse = DeviceGetIsIdentifiedResponse

class DeviceGetAxisIdentityRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    axis: builtin___int = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        axis : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"axis",b"axis",u"device",b"device",u"interface_id",b"interface_id"]) -> None: ...
type___DeviceGetAxisIdentityRequest = DeviceGetAxisIdentityRequest

class DeviceGetAxisIdentityResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def identity(self) -> type___AxisIdentity: ...

    def __init__(self,
        *,
        identity : typing___Optional[type___AxisIdentity] = None,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions___Literal[u"identity",b"identity"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"identity",b"identity"]) -> None: ...
type___DeviceGetAxisIdentityResponse = DeviceGetAxisIdentityResponse

class DeviceIsBusyRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    axis: builtin___int = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        axis : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"axis",b"axis",u"device",b"device",u"interface_id",b"interface_id"]) -> None: ...
type___DeviceIsBusyRequest = DeviceIsBusyRequest

class DeviceIsBusyResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    is_busy: builtin___bool = ...

    def __init__(self,
        *,
        is_busy : typing___Optional[builtin___bool] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"is_busy",b"is_busy"]) -> None: ...
type___DeviceIsBusyResponse = DeviceIsBusyResponse

class DeviceGetWarningsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    axis: builtin___int = ...
    clear: builtin___bool = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        axis : typing___Optional[builtin___int] = None,
        clear : typing___Optional[builtin___bool] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"axis",b"axis",u"clear",b"clear",u"device",b"device",u"interface_id",b"interface_id"]) -> None: ...
type___DeviceGetWarningsRequest = DeviceGetWarningsRequest

class DeviceGetWarningsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    flags: google___protobuf___internal___containers___RepeatedScalarFieldContainer[typing___Text] = ...

    def __init__(self,
        *,
        flags : typing___Optional[typing___Iterable[typing___Text]] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"flags",b"flags"]) -> None: ...
type___DeviceGetWarningsResponse = DeviceGetWarningsResponse

class DeviceGetAllDigitalIORequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    channel_type: typing___Text = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        channel_type : typing___Optional[typing___Text] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"channel_type",b"channel_type",u"device",b"device",u"interface_id",b"interface_id"]) -> None: ...
type___DeviceGetAllDigitalIORequest = DeviceGetAllDigitalIORequest

class DeviceGetAllDigitalIOResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    values: google___protobuf___internal___containers___RepeatedScalarFieldContainer[builtin___bool] = ...

    def __init__(self,
        *,
        values : typing___Optional[typing___Iterable[builtin___bool]] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"values",b"values"]) -> None: ...
type___DeviceGetAllDigitalIOResponse = DeviceGetAllDigitalIOResponse

class DeviceGetAllAnalogIORequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    channel_type: typing___Text = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        channel_type : typing___Optional[typing___Text] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"channel_type",b"channel_type",u"device",b"device",u"interface_id",b"interface_id"]) -> None: ...
type___DeviceGetAllAnalogIORequest = DeviceGetAllAnalogIORequest

class DeviceGetAllAnalogIOResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    values: google___protobuf___internal___containers___RepeatedScalarFieldContainer[builtin___float] = ...

    def __init__(self,
        *,
        values : typing___Optional[typing___Iterable[builtin___float]] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"values",b"values"]) -> None: ...
type___DeviceGetAllAnalogIOResponse = DeviceGetAllAnalogIOResponse

class DeviceGetDigitalIORequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    channel_type: typing___Text = ...
    channel_number: builtin___int = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        channel_type : typing___Optional[typing___Text] = None,
        channel_number : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"channel_number",b"channel_number",u"channel_type",b"channel_type",u"device",b"device",u"interface_id",b"interface_id"]) -> None: ...
type___DeviceGetDigitalIORequest = DeviceGetDigitalIORequest

class DeviceGetDigitalIOResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    value: builtin___bool = ...

    def __init__(self,
        *,
        value : typing___Optional[builtin___bool] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"value",b"value"]) -> None: ...
type___DeviceGetDigitalIOResponse = DeviceGetDigitalIOResponse

class DeviceGetAnalogIORequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    channel_type: typing___Text = ...
    channel_number: builtin___int = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        channel_type : typing___Optional[typing___Text] = None,
        channel_number : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"channel_number",b"channel_number",u"channel_type",b"channel_type",u"device",b"device",u"interface_id",b"interface_id"]) -> None: ...
type___DeviceGetAnalogIORequest = DeviceGetAnalogIORequest

class DeviceGetAnalogIOResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    value: builtin___float = ...

    def __init__(self,
        *,
        value : typing___Optional[builtin___float] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"value",b"value"]) -> None: ...
type___DeviceGetAnalogIOResponse = DeviceGetAnalogIOResponse

class DeviceSetAllDigitalOutputsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    values: google___protobuf___internal___containers___RepeatedScalarFieldContainer[builtin___bool] = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        values : typing___Optional[typing___Iterable[builtin___bool]] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device",b"device",u"interface_id",b"interface_id",u"values",b"values"]) -> None: ...
type___DeviceSetAllDigitalOutputsRequest = DeviceSetAllDigitalOutputsRequest

class DeviceSetAllAnalogOutputsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    values: google___protobuf___internal___containers___RepeatedScalarFieldContainer[builtin___float] = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        values : typing___Optional[typing___Iterable[builtin___float]] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device",b"device",u"interface_id",b"interface_id",u"values",b"values"]) -> None: ...
type___DeviceSetAllAnalogOutputsRequest = DeviceSetAllAnalogOutputsRequest

class DeviceSetDigitalOutputRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    channel_number: builtin___int = ...
    value: builtin___bool = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        channel_number : typing___Optional[builtin___int] = None,
        value : typing___Optional[builtin___bool] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"channel_number",b"channel_number",u"device",b"device",u"interface_id",b"interface_id",u"value",b"value"]) -> None: ...
type___DeviceSetDigitalOutputRequest = DeviceSetDigitalOutputRequest

class DeviceSetAnalogOutputRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    channel_number: builtin___int = ...
    value: builtin___float = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        channel_number : typing___Optional[builtin___int] = None,
        value : typing___Optional[builtin___float] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"channel_number",b"channel_number",u"device",b"device",u"interface_id",b"interface_id",u"value",b"value"]) -> None: ...
type___DeviceSetAnalogOutputRequest = DeviceSetAnalogOutputRequest

class DeviceGetIOChannelsInfoRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device",b"device",u"interface_id",b"interface_id"]) -> None: ...
type___DeviceGetIOChannelsInfoRequest = DeviceGetIOChannelsInfoRequest

class SetLogOutputRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    mode: builtin___int = ...
    file_path: typing___Text = ...

    def __init__(self,
        *,
        mode : typing___Optional[builtin___int] = None,
        file_path : typing___Optional[typing___Text] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"file_path",b"file_path",u"mode",b"mode"]) -> None: ...
type___SetLogOutputRequest = SetLogOutputRequest

class DeviceGetSettingRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    axis: builtin___int = ...
    setting: typing___Text = ...
    unit: typing___Text = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        axis : typing___Optional[builtin___int] = None,
        setting : typing___Optional[typing___Text] = None,
        unit : typing___Optional[typing___Text] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"axis",b"axis",u"device",b"device",u"interface_id",b"interface_id",u"setting",b"setting",u"unit",b"unit"]) -> None: ...
type___DeviceGetSettingRequest = DeviceGetSettingRequest

class DeviceGetSettingResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    value: builtin___float = ...

    def __init__(self,
        *,
        value : typing___Optional[builtin___float] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"value",b"value"]) -> None: ...
type___DeviceGetSettingResponse = DeviceGetSettingResponse

class DeviceConvertSettingRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    axis: builtin___int = ...
    setting: typing___Text = ...
    unit: typing___Text = ...
    value: builtin___float = ...
    from_native: builtin___bool = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        axis : typing___Optional[builtin___int] = None,
        setting : typing___Optional[typing___Text] = None,
        unit : typing___Optional[typing___Text] = None,
        value : typing___Optional[builtin___float] = None,
        from_native : typing___Optional[builtin___bool] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"axis",b"axis",u"device",b"device",u"from_native",b"from_native",u"interface_id",b"interface_id",u"setting",b"setting",u"unit",b"unit",u"value",b"value"]) -> None: ...
type___DeviceConvertSettingRequest = DeviceConvertSettingRequest

class DeviceConvertSettingResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    value: builtin___float = ...

    def __init__(self,
        *,
        value : typing___Optional[builtin___float] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"value",b"value"]) -> None: ...
type___DeviceConvertSettingResponse = DeviceConvertSettingResponse

class DeviceSetSettingRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    axis: builtin___int = ...
    setting: typing___Text = ...
    value: builtin___float = ...
    unit: typing___Text = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        axis : typing___Optional[builtin___int] = None,
        setting : typing___Optional[typing___Text] = None,
        value : typing___Optional[builtin___float] = None,
        unit : typing___Optional[typing___Text] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"axis",b"axis",u"device",b"device",u"interface_id",b"interface_id",u"setting",b"setting",u"unit",b"unit",u"value",b"value"]) -> None: ...
type___DeviceSetSettingRequest = DeviceSetSettingRequest

class PrepareCommandRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    axis: builtin___int = ...
    command_template: typing___Text = ...

    @property
    def parameters(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___Measurement]: ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        axis : typing___Optional[builtin___int] = None,
        command_template : typing___Optional[typing___Text] = None,
        parameters : typing___Optional[typing___Iterable[type___Measurement]] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"axis",b"axis",u"command_template",b"command_template",u"device",b"device",u"interface_id",b"interface_id",u"parameters",b"parameters"]) -> None: ...
type___PrepareCommandRequest = PrepareCommandRequest

class PrepareCommandResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    command: typing___Text = ...

    def __init__(self,
        *,
        command : typing___Optional[typing___Text] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"command",b"command"]) -> None: ...
type___PrepareCommandResponse = PrepareCommandResponse

class DeviceParkRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    axis: builtin___int = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        axis : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"axis",b"axis",u"device",b"device",u"interface_id",b"interface_id"]) -> None: ...
type___DeviceParkRequest = DeviceParkRequest

class DeviceIsParkedResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    is_parked: builtin___bool = ...

    def __init__(self,
        *,
        is_parked : typing___Optional[builtin___bool] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"is_parked",b"is_parked"]) -> None: ...
type___DeviceIsParkedResponse = DeviceIsParkedResponse

class LockstepEnableRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    lockstep_group_id: builtin___int = ...
    axes: google___protobuf___internal___containers___RepeatedScalarFieldContainer[builtin___int] = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        lockstep_group_id : typing___Optional[builtin___int] = None,
        axes : typing___Optional[typing___Iterable[builtin___int]] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"axes",b"axes",u"device",b"device",u"interface_id",b"interface_id",u"lockstep_group_id",b"lockstep_group_id"]) -> None: ...
type___LockstepEnableRequest = LockstepEnableRequest

class LockstepDisableRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    lockstep_group_id: builtin___int = ...
    wait_until_idle: builtin___bool = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        lockstep_group_id : typing___Optional[builtin___int] = None,
        wait_until_idle : typing___Optional[builtin___bool] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device",b"device",u"interface_id",b"interface_id",u"lockstep_group_id",b"lockstep_group_id",u"wait_until_idle",b"wait_until_idle"]) -> None: ...
type___LockstepDisableRequest = LockstepDisableRequest

class LockstepStopRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    lockstep_group_id: builtin___int = ...
    wait_until_idle: builtin___bool = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        lockstep_group_id : typing___Optional[builtin___int] = None,
        wait_until_idle : typing___Optional[builtin___bool] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device",b"device",u"interface_id",b"interface_id",u"lockstep_group_id",b"lockstep_group_id",u"wait_until_idle",b"wait_until_idle"]) -> None: ...
type___LockstepStopRequest = LockstepStopRequest

class LockstepHomeRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    lockstep_group_id: builtin___int = ...
    wait_until_idle: builtin___bool = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        lockstep_group_id : typing___Optional[builtin___int] = None,
        wait_until_idle : typing___Optional[builtin___bool] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device",b"device",u"interface_id",b"interface_id",u"lockstep_group_id",b"lockstep_group_id",u"wait_until_idle",b"wait_until_idle"]) -> None: ...
type___LockstepHomeRequest = LockstepHomeRequest

class LockstepMoveRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    MoveTypeValue = typing___NewType('MoveTypeValue', builtin___int)
    type___MoveTypeValue = MoveTypeValue
    MoveType: _MoveType
    class _MoveType(google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[LockstepMoveRequest.MoveTypeValue]):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        ABS = typing___cast(LockstepMoveRequest.MoveTypeValue, 0)
        REL = typing___cast(LockstepMoveRequest.MoveTypeValue, 1)
        VEL = typing___cast(LockstepMoveRequest.MoveTypeValue, 2)
        MAX = typing___cast(LockstepMoveRequest.MoveTypeValue, 3)
        MIN = typing___cast(LockstepMoveRequest.MoveTypeValue, 4)
    ABS = typing___cast(LockstepMoveRequest.MoveTypeValue, 0)
    REL = typing___cast(LockstepMoveRequest.MoveTypeValue, 1)
    VEL = typing___cast(LockstepMoveRequest.MoveTypeValue, 2)
    MAX = typing___cast(LockstepMoveRequest.MoveTypeValue, 3)
    MIN = typing___cast(LockstepMoveRequest.MoveTypeValue, 4)

    interface_id: builtin___int = ...
    device: builtin___int = ...
    lockstep_group_id: builtin___int = ...
    wait_until_idle: builtin___bool = ...
    type: type___LockstepMoveRequest.MoveTypeValue = ...
    arg: builtin___float = ...
    unit: typing___Text = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        lockstep_group_id : typing___Optional[builtin___int] = None,
        wait_until_idle : typing___Optional[builtin___bool] = None,
        type : typing___Optional[type___LockstepMoveRequest.MoveTypeValue] = None,
        arg : typing___Optional[builtin___float] = None,
        unit : typing___Optional[typing___Text] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"arg",b"arg",u"device",b"device",u"interface_id",b"interface_id",u"lockstep_group_id",b"lockstep_group_id",u"type",b"type",u"unit",b"unit",u"wait_until_idle",b"wait_until_idle"]) -> None: ...
type___LockstepMoveRequest = LockstepMoveRequest

class LockstepWaitUntilIdleRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    lockstep_group_id: builtin___int = ...
    throw_error_on_fault: builtin___bool = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        lockstep_group_id : typing___Optional[builtin___int] = None,
        throw_error_on_fault : typing___Optional[builtin___bool] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device",b"device",u"interface_id",b"interface_id",u"lockstep_group_id",b"lockstep_group_id",u"throw_error_on_fault",b"throw_error_on_fault"]) -> None: ...
type___LockstepWaitUntilIdleRequest = LockstepWaitUntilIdleRequest

class LockstepIsBusyRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    lockstep_group_id: builtin___int = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        lockstep_group_id : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device",b"device",u"interface_id",b"interface_id",u"lockstep_group_id",b"lockstep_group_id"]) -> None: ...
type___LockstepIsBusyRequest = LockstepIsBusyRequest

class LockstepIsBusyResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    is_busy: builtin___bool = ...

    def __init__(self,
        *,
        is_busy : typing___Optional[builtin___bool] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"is_busy",b"is_busy"]) -> None: ...
type___LockstepIsBusyResponse = LockstepIsBusyResponse

class LockstepGetAxesRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    lockstep_group_id: builtin___int = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        lockstep_group_id : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device",b"device",u"interface_id",b"interface_id",u"lockstep_group_id",b"lockstep_group_id"]) -> None: ...
type___LockstepGetAxesRequest = LockstepGetAxesRequest

class LockstepAxes(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    axis_1: builtin___int = ...
    axis_2: builtin___int = ...
    axis_3: builtin___int = ...
    axis_4: builtin___int = ...

    def __init__(self,
        *,
        axis_1 : typing___Optional[builtin___int] = None,
        axis_2 : typing___Optional[builtin___int] = None,
        axis_3 : typing___Optional[builtin___int] = None,
        axis_4 : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"axis_1",b"axis_1",u"axis_2",b"axis_2",u"axis_3",b"axis_3",u"axis_4",b"axis_4"]) -> None: ...
type___LockstepAxes = LockstepAxes

class LockstepGetAxesResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def axes(self) -> type___LockstepAxes: ...

    def __init__(self,
        *,
        axes : typing___Optional[type___LockstepAxes] = None,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions___Literal[u"axes",b"axes"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"axes",b"axes"]) -> None: ...
type___LockstepGetAxesResponse = LockstepGetAxesResponse

class LockstepGetTwistsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    lockstep_group_id: builtin___int = ...
    unit: typing___Text = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        lockstep_group_id : typing___Optional[builtin___int] = None,
        unit : typing___Optional[typing___Text] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device",b"device",u"interface_id",b"interface_id",u"lockstep_group_id",b"lockstep_group_id",u"unit",b"unit"]) -> None: ...
type___LockstepGetTwistsRequest = LockstepGetTwistsRequest

class LockstepGetTwistsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    twists: google___protobuf___internal___containers___RepeatedScalarFieldContainer[builtin___float] = ...

    def __init__(self,
        *,
        twists : typing___Optional[typing___Iterable[builtin___float]] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"twists",b"twists"]) -> None: ...
type___LockstepGetTwistsResponse = LockstepGetTwistsResponse

class LockstepGetOffsetsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    lockstep_group_id: builtin___int = ...
    unit: typing___Text = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        lockstep_group_id : typing___Optional[builtin___int] = None,
        unit : typing___Optional[typing___Text] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device",b"device",u"interface_id",b"interface_id",u"lockstep_group_id",b"lockstep_group_id",u"unit",b"unit"]) -> None: ...
type___LockstepGetOffsetsRequest = LockstepGetOffsetsRequest

class LockstepGetOffsetsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    offsets: google___protobuf___internal___containers___RepeatedScalarFieldContainer[builtin___float] = ...

    def __init__(self,
        *,
        offsets : typing___Optional[typing___Iterable[builtin___float]] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"offsets",b"offsets"]) -> None: ...
type___LockstepGetOffsetsResponse = LockstepGetOffsetsResponse

class LockstepIsEnabledRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    lockstep_group_id: builtin___int = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        lockstep_group_id : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device",b"device",u"interface_id",b"interface_id",u"lockstep_group_id",b"lockstep_group_id"]) -> None: ...
type___LockstepIsEnabledRequest = LockstepIsEnabledRequest

class LockstepIsEnabledResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    is_enabled: builtin___bool = ...

    def __init__(self,
        *,
        is_enabled : typing___Optional[builtin___bool] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"is_enabled",b"is_enabled"]) -> None: ...
type___LockstepIsEnabledResponse = LockstepIsEnabledResponse

class LockstepToStringRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    lockstep_group_id: builtin___int = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        lockstep_group_id : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device",b"device",u"interface_id",b"interface_id",u"lockstep_group_id",b"lockstep_group_id"]) -> None: ...
type___LockstepToStringRequest = LockstepToStringRequest

class LockstepToStringResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    to_str: typing___Text = ...

    def __init__(self,
        *,
        to_str : typing___Optional[typing___Text] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"to_str",b"to_str"]) -> None: ...
type___LockstepToStringResponse = LockstepToStringResponse

class StreamSetupLiveRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    stream_id: builtin___int = ...
    axes: google___protobuf___internal___containers___RepeatedScalarFieldContainer[builtin___int] = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        stream_id : typing___Optional[builtin___int] = None,
        axes : typing___Optional[typing___Iterable[builtin___int]] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"axes",b"axes",u"device",b"device",u"interface_id",b"interface_id",u"stream_id",b"stream_id"]) -> None: ...
type___StreamSetupLiveRequest = StreamSetupLiveRequest

class StreamSetupLiveCompositeRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    stream_id: builtin___int = ...

    @property
    def axes(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___StreamAxisDefinition]: ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        stream_id : typing___Optional[builtin___int] = None,
        axes : typing___Optional[typing___Iterable[type___StreamAxisDefinition]] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"axes",b"axes",u"device",b"device",u"interface_id",b"interface_id",u"stream_id",b"stream_id"]) -> None: ...
type___StreamSetupLiveCompositeRequest = StreamSetupLiveCompositeRequest

class StreamSetupStoreRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    stream_id: builtin___int = ...
    stream_buffer: builtin___int = ...
    axes: google___protobuf___internal___containers___RepeatedScalarFieldContainer[builtin___int] = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        stream_id : typing___Optional[builtin___int] = None,
        stream_buffer : typing___Optional[builtin___int] = None,
        axes : typing___Optional[typing___Iterable[builtin___int]] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"axes",b"axes",u"device",b"device",u"interface_id",b"interface_id",u"stream_buffer",b"stream_buffer",u"stream_id",b"stream_id"]) -> None: ...
type___StreamSetupStoreRequest = StreamSetupStoreRequest

class StreamSetupStoreCompositeRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    stream_id: builtin___int = ...
    stream_buffer: builtin___int = ...

    @property
    def axes(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___StreamAxisDefinition]: ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        stream_id : typing___Optional[builtin___int] = None,
        stream_buffer : typing___Optional[builtin___int] = None,
        axes : typing___Optional[typing___Iterable[type___StreamAxisDefinition]] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"axes",b"axes",u"device",b"device",u"interface_id",b"interface_id",u"stream_buffer",b"stream_buffer",u"stream_id",b"stream_id"]) -> None: ...
type___StreamSetupStoreCompositeRequest = StreamSetupStoreCompositeRequest

class StreamSetupStoreArbitraryAxesRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    stream_id: builtin___int = ...
    stream_buffer: builtin___int = ...
    axes_count: builtin___int = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        stream_id : typing___Optional[builtin___int] = None,
        stream_buffer : typing___Optional[builtin___int] = None,
        axes_count : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"axes_count",b"axes_count",u"device",b"device",u"interface_id",b"interface_id",u"stream_buffer",b"stream_buffer",u"stream_id",b"stream_id"]) -> None: ...
type___StreamSetupStoreArbitraryAxesRequest = StreamSetupStoreArbitraryAxesRequest

class StreamCallRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    stream_id: builtin___int = ...
    stream_buffer: builtin___int = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        stream_id : typing___Optional[builtin___int] = None,
        stream_buffer : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device",b"device",u"interface_id",b"interface_id",u"stream_buffer",b"stream_buffer",u"stream_id",b"stream_id"]) -> None: ...
type___StreamCallRequest = StreamCallRequest

class StreamLineRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    TypeValue = typing___NewType('TypeValue', builtin___int)
    type___TypeValue = TypeValue
    Type: _Type
    class _Type(google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[StreamLineRequest.TypeValue]):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        ABS = typing___cast(StreamLineRequest.TypeValue, 0)
        REL = typing___cast(StreamLineRequest.TypeValue, 1)
    ABS = typing___cast(StreamLineRequest.TypeValue, 0)
    REL = typing___cast(StreamLineRequest.TypeValue, 1)

    interface_id: builtin___int = ...
    device: builtin___int = ...
    stream_id: builtin___int = ...
    type: type___StreamLineRequest.TypeValue = ...
    target_axes_indices: google___protobuf___internal___containers___RepeatedScalarFieldContainer[builtin___int] = ...

    @property
    def endpoint(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___Measurement]: ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        stream_id : typing___Optional[builtin___int] = None,
        type : typing___Optional[type___StreamLineRequest.TypeValue] = None,
        endpoint : typing___Optional[typing___Iterable[type___Measurement]] = None,
        target_axes_indices : typing___Optional[typing___Iterable[builtin___int]] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device",b"device",u"endpoint",b"endpoint",u"interface_id",b"interface_id",u"stream_id",b"stream_id",u"target_axes_indices",b"target_axes_indices",u"type",b"type"]) -> None: ...
type___StreamLineRequest = StreamLineRequest

class StreamArcRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    TypeValue = typing___NewType('TypeValue', builtin___int)
    type___TypeValue = TypeValue
    Type: _Type
    class _Type(google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[StreamArcRequest.TypeValue]):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        ABS = typing___cast(StreamArcRequest.TypeValue, 0)
        REL = typing___cast(StreamArcRequest.TypeValue, 1)
    ABS = typing___cast(StreamArcRequest.TypeValue, 0)
    REL = typing___cast(StreamArcRequest.TypeValue, 1)

    interface_id: builtin___int = ...
    device: builtin___int = ...
    stream_id: builtin___int = ...
    type: type___StreamArcRequest.TypeValue = ...
    rotation_direction: builtin___int = ...
    target_axes_indices: google___protobuf___internal___containers___RepeatedScalarFieldContainer[builtin___int] = ...

    @property
    def center_x(self) -> type___Measurement: ...

    @property
    def center_y(self) -> type___Measurement: ...

    @property
    def end_x(self) -> type___Measurement: ...

    @property
    def end_y(self) -> type___Measurement: ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        stream_id : typing___Optional[builtin___int] = None,
        type : typing___Optional[type___StreamArcRequest.TypeValue] = None,
        rotation_direction : typing___Optional[builtin___int] = None,
        center_x : typing___Optional[type___Measurement] = None,
        center_y : typing___Optional[type___Measurement] = None,
        end_x : typing___Optional[type___Measurement] = None,
        end_y : typing___Optional[type___Measurement] = None,
        target_axes_indices : typing___Optional[typing___Iterable[builtin___int]] = None,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions___Literal[u"center_x",b"center_x",u"center_y",b"center_y",u"end_x",b"end_x",u"end_y",b"end_y"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"center_x",b"center_x",u"center_y",b"center_y",u"device",b"device",u"end_x",b"end_x",u"end_y",b"end_y",u"interface_id",b"interface_id",u"rotation_direction",b"rotation_direction",u"stream_id",b"stream_id",u"target_axes_indices",b"target_axes_indices",u"type",b"type"]) -> None: ...
type___StreamArcRequest = StreamArcRequest

class StreamCircleRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    TypeValue = typing___NewType('TypeValue', builtin___int)
    type___TypeValue = TypeValue
    Type: _Type
    class _Type(google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[StreamCircleRequest.TypeValue]):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        ABS = typing___cast(StreamCircleRequest.TypeValue, 0)
        REL = typing___cast(StreamCircleRequest.TypeValue, 1)
    ABS = typing___cast(StreamCircleRequest.TypeValue, 0)
    REL = typing___cast(StreamCircleRequest.TypeValue, 1)

    interface_id: builtin___int = ...
    device: builtin___int = ...
    stream_id: builtin___int = ...
    type: type___StreamCircleRequest.TypeValue = ...
    rotation_direction: builtin___int = ...
    target_axes_indices: google___protobuf___internal___containers___RepeatedScalarFieldContainer[builtin___int] = ...

    @property
    def center_x(self) -> type___Measurement: ...

    @property
    def center_y(self) -> type___Measurement: ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        stream_id : typing___Optional[builtin___int] = None,
        type : typing___Optional[type___StreamCircleRequest.TypeValue] = None,
        rotation_direction : typing___Optional[builtin___int] = None,
        center_x : typing___Optional[type___Measurement] = None,
        center_y : typing___Optional[type___Measurement] = None,
        target_axes_indices : typing___Optional[typing___Iterable[builtin___int]] = None,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions___Literal[u"center_x",b"center_x",u"center_y",b"center_y"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"center_x",b"center_x",u"center_y",b"center_y",u"device",b"device",u"interface_id",b"interface_id",u"rotation_direction",b"rotation_direction",u"stream_id",b"stream_id",u"target_axes_indices",b"target_axes_indices",u"type",b"type"]) -> None: ...
type___StreamCircleRequest = StreamCircleRequest

class StreamWaitDigitalInputRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    stream_id: builtin___int = ...
    channel_number: builtin___int = ...
    value: builtin___bool = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        stream_id : typing___Optional[builtin___int] = None,
        channel_number : typing___Optional[builtin___int] = None,
        value : typing___Optional[builtin___bool] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"channel_number",b"channel_number",u"device",b"device",u"interface_id",b"interface_id",u"stream_id",b"stream_id",u"value",b"value"]) -> None: ...
type___StreamWaitDigitalInputRequest = StreamWaitDigitalInputRequest

class StreamWaitAnalogInputRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    stream_id: builtin___int = ...
    channel_number: builtin___int = ...
    condition: typing___Text = ...
    value: builtin___float = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        stream_id : typing___Optional[builtin___int] = None,
        channel_number : typing___Optional[builtin___int] = None,
        condition : typing___Optional[typing___Text] = None,
        value : typing___Optional[builtin___float] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"channel_number",b"channel_number",u"condition",b"condition",u"device",b"device",u"interface_id",b"interface_id",u"stream_id",b"stream_id",u"value",b"value"]) -> None: ...
type___StreamWaitAnalogInputRequest = StreamWaitAnalogInputRequest

class StreamSetDigitalOutputRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    stream_id: builtin___int = ...
    channel_number: builtin___int = ...
    value: builtin___bool = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        stream_id : typing___Optional[builtin___int] = None,
        channel_number : typing___Optional[builtin___int] = None,
        value : typing___Optional[builtin___bool] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"channel_number",b"channel_number",u"device",b"device",u"interface_id",b"interface_id",u"stream_id",b"stream_id",u"value",b"value"]) -> None: ...
type___StreamSetDigitalOutputRequest = StreamSetDigitalOutputRequest

class StreamSetAnalogOutputRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    stream_id: builtin___int = ...
    channel_number: builtin___int = ...
    value: builtin___float = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        stream_id : typing___Optional[builtin___int] = None,
        channel_number : typing___Optional[builtin___int] = None,
        value : typing___Optional[builtin___float] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"channel_number",b"channel_number",u"device",b"device",u"interface_id",b"interface_id",u"stream_id",b"stream_id",u"value",b"value"]) -> None: ...
type___StreamSetAnalogOutputRequest = StreamSetAnalogOutputRequest

class StreamToggleDigitalOutputRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    stream_id: builtin___int = ...
    channel_number: builtin___int = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        stream_id : typing___Optional[builtin___int] = None,
        channel_number : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"channel_number",b"channel_number",u"device",b"device",u"interface_id",b"interface_id",u"stream_id",b"stream_id"]) -> None: ...
type___StreamToggleDigitalOutputRequest = StreamToggleDigitalOutputRequest

class StreamWaitRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    stream_id: builtin___int = ...
    time: builtin___float = ...
    unit: typing___Text = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        stream_id : typing___Optional[builtin___int] = None,
        time : typing___Optional[builtin___float] = None,
        unit : typing___Optional[typing___Text] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device",b"device",u"interface_id",b"interface_id",u"stream_id",b"stream_id",u"time",b"time",u"unit",b"unit"]) -> None: ...
type___StreamWaitRequest = StreamWaitRequest

class StreamWaitUntilIdleRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    stream_id: builtin___int = ...
    throw_error_on_fault: builtin___bool = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        stream_id : typing___Optional[builtin___int] = None,
        throw_error_on_fault : typing___Optional[builtin___bool] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device",b"device",u"interface_id",b"interface_id",u"stream_id",b"stream_id",u"throw_error_on_fault",b"throw_error_on_fault"]) -> None: ...
type___StreamWaitUntilIdleRequest = StreamWaitUntilIdleRequest

class StreamCorkRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    stream_id: builtin___int = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        stream_id : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device",b"device",u"interface_id",b"interface_id",u"stream_id",b"stream_id"]) -> None: ...
type___StreamCorkRequest = StreamCorkRequest

class StreamUncorkRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    stream_id: builtin___int = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        stream_id : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device",b"device",u"interface_id",b"interface_id",u"stream_id",b"stream_id"]) -> None: ...
type___StreamUncorkRequest = StreamUncorkRequest

class StreamIsBusyRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    stream_id: builtin___int = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        stream_id : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device",b"device",u"interface_id",b"interface_id",u"stream_id",b"stream_id"]) -> None: ...
type___StreamIsBusyRequest = StreamIsBusyRequest

class StreamIsBusyResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    is_busy: builtin___bool = ...

    def __init__(self,
        *,
        is_busy : typing___Optional[builtin___bool] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"is_busy",b"is_busy"]) -> None: ...
type___StreamIsBusyResponse = StreamIsBusyResponse

class StreamGetAxesRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    stream_id: builtin___int = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        stream_id : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device",b"device",u"interface_id",b"interface_id",u"stream_id",b"stream_id"]) -> None: ...
type___StreamGetAxesRequest = StreamGetAxesRequest

class StreamGetAxesResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def axes(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___StreamAxisDefinition]: ...

    def __init__(self,
        *,
        axes : typing___Optional[typing___Iterable[type___StreamAxisDefinition]] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"axes",b"axes"]) -> None: ...
type___StreamGetAxesResponse = StreamGetAxesResponse

class StreamGetModeRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    stream_id: builtin___int = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        stream_id : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device",b"device",u"interface_id",b"interface_id",u"stream_id",b"stream_id"]) -> None: ...
type___StreamGetModeRequest = StreamGetModeRequest

class StreamGetModeResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    mode: builtin___int = ...

    def __init__(self,
        *,
        mode : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"mode",b"mode"]) -> None: ...
type___StreamGetModeResponse = StreamGetModeResponse

class StreamGetMaxSpeedRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    stream_id: builtin___int = ...
    unit: typing___Text = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        stream_id : typing___Optional[builtin___int] = None,
        unit : typing___Optional[typing___Text] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device",b"device",u"interface_id",b"interface_id",u"stream_id",b"stream_id",u"unit",b"unit"]) -> None: ...
type___StreamGetMaxSpeedRequest = StreamGetMaxSpeedRequest

class StreamGetMaxSpeedResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    max_speed: builtin___float = ...

    def __init__(self,
        *,
        max_speed : typing___Optional[builtin___float] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"max_speed",b"max_speed"]) -> None: ...
type___StreamGetMaxSpeedResponse = StreamGetMaxSpeedResponse

class StreamSetMaxSpeedRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    stream_id: builtin___int = ...
    max_speed: builtin___float = ...
    unit: typing___Text = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        stream_id : typing___Optional[builtin___int] = None,
        max_speed : typing___Optional[builtin___float] = None,
        unit : typing___Optional[typing___Text] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device",b"device",u"interface_id",b"interface_id",u"max_speed",b"max_speed",u"stream_id",b"stream_id",u"unit",b"unit"]) -> None: ...
type___StreamSetMaxSpeedRequest = StreamSetMaxSpeedRequest

class StreamGetMaxTangentialAccelerationRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    stream_id: builtin___int = ...
    unit: typing___Text = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        stream_id : typing___Optional[builtin___int] = None,
        unit : typing___Optional[typing___Text] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device",b"device",u"interface_id",b"interface_id",u"stream_id",b"stream_id",u"unit",b"unit"]) -> None: ...
type___StreamGetMaxTangentialAccelerationRequest = StreamGetMaxTangentialAccelerationRequest

class StreamGetMaxTangentialAccelerationResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    max_tangential_acceleration: builtin___float = ...

    def __init__(self,
        *,
        max_tangential_acceleration : typing___Optional[builtin___float] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"max_tangential_acceleration",b"max_tangential_acceleration"]) -> None: ...
type___StreamGetMaxTangentialAccelerationResponse = StreamGetMaxTangentialAccelerationResponse

class StreamSetMaxTangentialAccelerationRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    stream_id: builtin___int = ...
    max_tangential_acceleration: builtin___float = ...
    unit: typing___Text = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        stream_id : typing___Optional[builtin___int] = None,
        max_tangential_acceleration : typing___Optional[builtin___float] = None,
        unit : typing___Optional[typing___Text] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device",b"device",u"interface_id",b"interface_id",u"max_tangential_acceleration",b"max_tangential_acceleration",u"stream_id",b"stream_id",u"unit",b"unit"]) -> None: ...
type___StreamSetMaxTangentialAccelerationRequest = StreamSetMaxTangentialAccelerationRequest

class StreamGetMaxCentripetalAccelerationRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    stream_id: builtin___int = ...
    unit: typing___Text = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        stream_id : typing___Optional[builtin___int] = None,
        unit : typing___Optional[typing___Text] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device",b"device",u"interface_id",b"interface_id",u"stream_id",b"stream_id",u"unit",b"unit"]) -> None: ...
type___StreamGetMaxCentripetalAccelerationRequest = StreamGetMaxCentripetalAccelerationRequest

class StreamGetMaxCentripetalAccelerationResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    max_centripetal_acceleration: builtin___float = ...

    def __init__(self,
        *,
        max_centripetal_acceleration : typing___Optional[builtin___float] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"max_centripetal_acceleration",b"max_centripetal_acceleration"]) -> None: ...
type___StreamGetMaxCentripetalAccelerationResponse = StreamGetMaxCentripetalAccelerationResponse

class StreamSetMaxCentripetalAccelerationRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    stream_id: builtin___int = ...
    max_centripetal_acceleration: builtin___float = ...
    unit: typing___Text = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        stream_id : typing___Optional[builtin___int] = None,
        max_centripetal_acceleration : typing___Optional[builtin___float] = None,
        unit : typing___Optional[typing___Text] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device",b"device",u"interface_id",b"interface_id",u"max_centripetal_acceleration",b"max_centripetal_acceleration",u"stream_id",b"stream_id",u"unit",b"unit"]) -> None: ...
type___StreamSetMaxCentripetalAccelerationRequest = StreamSetMaxCentripetalAccelerationRequest

class StreamToStringRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    stream_id: builtin___int = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        stream_id : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device",b"device",u"interface_id",b"interface_id",u"stream_id",b"stream_id"]) -> None: ...
type___StreamToStringRequest = StreamToStringRequest

class StreamToStringResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    to_str: typing___Text = ...

    def __init__(self,
        *,
        to_str : typing___Optional[typing___Text] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"to_str",b"to_str"]) -> None: ...
type___StreamToStringResponse = StreamToStringResponse

class StreamDisableRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    stream_id: builtin___int = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        stream_id : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device",b"device",u"interface_id",b"interface_id",u"stream_id",b"stream_id"]) -> None: ...
type___StreamDisableRequest = StreamDisableRequest

class StreamBufferGetContentRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    buffer_id: builtin___int = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        buffer_id : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"buffer_id",b"buffer_id",u"device",b"device",u"interface_id",b"interface_id"]) -> None: ...
type___StreamBufferGetContentRequest = StreamBufferGetContentRequest

class StreamBufferGetContentResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    buffer_lines: google___protobuf___internal___containers___RepeatedScalarFieldContainer[typing___Text] = ...

    def __init__(self,
        *,
        buffer_lines : typing___Optional[typing___Iterable[typing___Text]] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"buffer_lines",b"buffer_lines"]) -> None: ...
type___StreamBufferGetContentResponse = StreamBufferGetContentResponse

class StreamBufferEraseRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    buffer_id: builtin___int = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        buffer_id : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"buffer_id",b"buffer_id",u"device",b"device",u"interface_id",b"interface_id"]) -> None: ...
type___StreamBufferEraseRequest = StreamBufferEraseRequest

class BinaryReplyOnlyEvent(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device_address: builtin___int = ...
    command: builtin___int = ...
    data: builtin___int = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device_address : typing___Optional[builtin___int] = None,
        command : typing___Optional[builtin___int] = None,
        data : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"command",b"command",u"data",b"data",u"device_address",b"device_address",u"interface_id",b"interface_id"]) -> None: ...
type___BinaryReplyOnlyEvent = BinaryReplyOnlyEvent

class OpenBinaryInterfaceRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_type: type___InterfaceTypeValue = ...
    port_name: typing___Text = ...
    baud_rate: builtin___int = ...
    host_name: typing___Text = ...
    port: builtin___int = ...
    use_message_ids: builtin___bool = ...

    def __init__(self,
        *,
        interface_type : typing___Optional[type___InterfaceTypeValue] = None,
        port_name : typing___Optional[typing___Text] = None,
        baud_rate : typing___Optional[builtin___int] = None,
        host_name : typing___Optional[typing___Text] = None,
        port : typing___Optional[builtin___int] = None,
        use_message_ids : typing___Optional[builtin___bool] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"baud_rate",b"baud_rate",u"host_name",b"host_name",u"interface_type",b"interface_type",u"port",b"port",u"port_name",b"port_name",u"use_message_ids",b"use_message_ids"]) -> None: ...
type___OpenBinaryInterfaceRequest = OpenBinaryInterfaceRequest

class UnknownBinaryResponseEvent(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device_address: builtin___int = ...
    command: builtin___int = ...
    data: builtin___int = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device_address : typing___Optional[builtin___int] = None,
        command : typing___Optional[builtin___int] = None,
        data : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"command",b"command",u"data",b"data",u"device_address",b"device_address",u"interface_id",b"interface_id"]) -> None: ...
type___UnknownBinaryResponseEvent = UnknownBinaryResponseEvent

class GenericBinaryRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    command: builtin___int = ...
    data: builtin___int = ...
    check_errors: builtin___bool = ...
    timeout: builtin___float = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        command : typing___Optional[builtin___int] = None,
        data : typing___Optional[builtin___int] = None,
        check_errors : typing___Optional[builtin___bool] = None,
        timeout : typing___Optional[builtin___float] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"check_errors",b"check_errors",u"command",b"command",u"data",b"data",u"device",b"device",u"interface_id",b"interface_id",u"timeout",b"timeout"]) -> None: ...
type___GenericBinaryRequest = GenericBinaryRequest

class BinaryMessage(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    device_address: builtin___int = ...
    command: builtin___int = ...
    data: builtin___int = ...

    def __init__(self,
        *,
        device_address : typing___Optional[builtin___int] = None,
        command : typing___Optional[builtin___int] = None,
        data : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"command",b"command",u"data",b"data",u"device_address",b"device_address"]) -> None: ...
type___BinaryMessage = BinaryMessage

class BinaryMessageCollection(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def messages(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___BinaryMessage]: ...

    def __init__(self,
        *,
        messages : typing___Optional[typing___Iterable[type___BinaryMessage]] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"messages",b"messages"]) -> None: ...
type___BinaryMessageCollection = BinaryMessageCollection

class BinaryDeviceRenumberRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"interface_id",b"interface_id"]) -> None: ...
type___BinaryDeviceRenumberRequest = BinaryDeviceRenumberRequest

class BinaryDeviceRenumberResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    number_devices: builtin___int = ...

    def __init__(self,
        *,
        number_devices : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"number_devices",b"number_devices"]) -> None: ...
type___BinaryDeviceRenumberResponse = BinaryDeviceRenumberResponse

class BinaryDeviceIdentifyRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device",b"device",u"interface_id",b"interface_id"]) -> None: ...
type___BinaryDeviceIdentifyRequest = BinaryDeviceIdentifyRequest

class BinaryDeviceIdentity(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    DeviceTypeValue = typing___NewType('DeviceTypeValue', builtin___int)
    type___DeviceTypeValue = DeviceTypeValue
    DeviceType: _DeviceType
    class _DeviceType(google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[BinaryDeviceIdentity.DeviceTypeValue]):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNKNOWN = typing___cast(BinaryDeviceIdentity.DeviceTypeValue, 0)
        LINEAR = typing___cast(BinaryDeviceIdentity.DeviceTypeValue, 1)
        ROTARY = typing___cast(BinaryDeviceIdentity.DeviceTypeValue, 2)
    UNKNOWN = typing___cast(BinaryDeviceIdentity.DeviceTypeValue, 0)
    LINEAR = typing___cast(BinaryDeviceIdentity.DeviceTypeValue, 1)
    ROTARY = typing___cast(BinaryDeviceIdentity.DeviceTypeValue, 2)

    device_id: builtin___int = ...
    serial_number: builtin___int = ...
    name: typing___Text = ...
    is_peripheral: builtin___bool = ...
    peripheral_id: builtin___int = ...
    peripheral_name: typing___Text = ...
    device_type: type___BinaryDeviceIdentity.DeviceTypeValue = ...

    @property
    def firmware_version(self) -> type___FirmwareVersion: ...

    def __init__(self,
        *,
        device_id : typing___Optional[builtin___int] = None,
        serial_number : typing___Optional[builtin___int] = None,
        name : typing___Optional[typing___Text] = None,
        firmware_version : typing___Optional[type___FirmwareVersion] = None,
        is_peripheral : typing___Optional[builtin___bool] = None,
        peripheral_id : typing___Optional[builtin___int] = None,
        peripheral_name : typing___Optional[typing___Text] = None,
        device_type : typing___Optional[type___BinaryDeviceIdentity.DeviceTypeValue] = None,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions___Literal[u"firmware_version",b"firmware_version"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device_id",b"device_id",u"device_type",b"device_type",u"firmware_version",b"firmware_version",u"is_peripheral",b"is_peripheral",u"name",b"name",u"peripheral_id",b"peripheral_id",u"peripheral_name",b"peripheral_name",u"serial_number",b"serial_number"]) -> None: ...
type___BinaryDeviceIdentity = BinaryDeviceIdentity

class BinaryDeviceGetIdentityRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device",b"device",u"interface_id",b"interface_id"]) -> None: ...
type___BinaryDeviceGetIdentityRequest = BinaryDeviceGetIdentityRequest

class BinaryDeviceGetIdentityResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def identity(self) -> type___BinaryDeviceIdentity: ...

    def __init__(self,
        *,
        identity : typing___Optional[type___BinaryDeviceIdentity] = None,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions___Literal[u"identity",b"identity"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"identity",b"identity"]) -> None: ...
type___BinaryDeviceGetIdentityResponse = BinaryDeviceGetIdentityResponse

class BinaryDeviceGetIsIdentifiedRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device",b"device",u"interface_id",b"interface_id"]) -> None: ...
type___BinaryDeviceGetIsIdentifiedRequest = BinaryDeviceGetIsIdentifiedRequest

class BinaryDeviceGetIsIdentifiedResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    is_identified: builtin___bool = ...

    def __init__(self,
        *,
        is_identified : typing___Optional[builtin___bool] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"is_identified",b"is_identified"]) -> None: ...
type___BinaryDeviceGetIsIdentifiedResponse = BinaryDeviceGetIsIdentifiedResponse

class BinaryGenericWithUnitsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    command: builtin___int = ...
    data: builtin___float = ...
    from_unit: typing___Text = ...
    to_unit: typing___Text = ...
    timeout: builtin___float = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        command : typing___Optional[builtin___int] = None,
        data : typing___Optional[builtin___float] = None,
        from_unit : typing___Optional[typing___Text] = None,
        to_unit : typing___Optional[typing___Text] = None,
        timeout : typing___Optional[builtin___float] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"command",b"command",u"data",b"data",u"device",b"device",u"from_unit",b"from_unit",u"interface_id",b"interface_id",u"timeout",b"timeout",u"to_unit",b"to_unit"]) -> None: ...
type___BinaryGenericWithUnitsRequest = BinaryGenericWithUnitsRequest

class BinaryGenericWithUnitsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    data: builtin___float = ...

    def __init__(self,
        *,
        data : typing___Optional[builtin___float] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"data",b"data"]) -> None: ...
type___BinaryGenericWithUnitsResponse = BinaryGenericWithUnitsResponse

class BinaryDeviceHomeRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    timeout: builtin___float = ...
    unit: typing___Text = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        timeout : typing___Optional[builtin___float] = None,
        unit : typing___Optional[typing___Text] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device",b"device",u"interface_id",b"interface_id",u"timeout",b"timeout",u"unit",b"unit"]) -> None: ...
type___BinaryDeviceHomeRequest = BinaryDeviceHomeRequest

class BinaryDeviceMovementResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    data: builtin___float = ...

    def __init__(self,
        *,
        data : typing___Optional[builtin___float] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"data",b"data"]) -> None: ...
type___BinaryDeviceMovementResponse = BinaryDeviceMovementResponse

class BinaryDeviceMoveRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    MoveTypeValue = typing___NewType('MoveTypeValue', builtin___int)
    type___MoveTypeValue = MoveTypeValue
    MoveType: _MoveType
    class _MoveType(google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[BinaryDeviceMoveRequest.MoveTypeValue]):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        ABS = typing___cast(BinaryDeviceMoveRequest.MoveTypeValue, 0)
        REL = typing___cast(BinaryDeviceMoveRequest.MoveTypeValue, 1)
        VEL = typing___cast(BinaryDeviceMoveRequest.MoveTypeValue, 2)
    ABS = typing___cast(BinaryDeviceMoveRequest.MoveTypeValue, 0)
    REL = typing___cast(BinaryDeviceMoveRequest.MoveTypeValue, 1)
    VEL = typing___cast(BinaryDeviceMoveRequest.MoveTypeValue, 2)

    interface_id: builtin___int = ...
    device: builtin___int = ...
    timeout: builtin___float = ...
    type: type___BinaryDeviceMoveRequest.MoveTypeValue = ...
    arg: builtin___float = ...
    unit: typing___Text = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        timeout : typing___Optional[builtin___float] = None,
        type : typing___Optional[type___BinaryDeviceMoveRequest.MoveTypeValue] = None,
        arg : typing___Optional[builtin___float] = None,
        unit : typing___Optional[typing___Text] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"arg",b"arg",u"device",b"device",u"interface_id",b"interface_id",u"timeout",b"timeout",u"type",b"type",u"unit",b"unit"]) -> None: ...
type___BinaryDeviceMoveRequest = BinaryDeviceMoveRequest

class BinaryDeviceStopRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    timeout: builtin___float = ...
    unit: typing___Text = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        timeout : typing___Optional[builtin___float] = None,
        unit : typing___Optional[typing___Text] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device",b"device",u"interface_id",b"interface_id",u"timeout",b"timeout",u"unit",b"unit"]) -> None: ...
type___BinaryDeviceStopRequest = BinaryDeviceStopRequest

class BinaryDeviceWaitUntilIdleRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device",b"device",u"interface_id",b"interface_id"]) -> None: ...
type___BinaryDeviceWaitUntilIdleRequest = BinaryDeviceWaitUntilIdleRequest

class BinaryDeviceIsBusyRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device",b"device",u"interface_id",b"interface_id"]) -> None: ...
type___BinaryDeviceIsBusyRequest = BinaryDeviceIsBusyRequest

class BinaryDeviceIsBusyResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    is_busy: builtin___bool = ...

    def __init__(self,
        *,
        is_busy : typing___Optional[builtin___bool] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"is_busy",b"is_busy"]) -> None: ...
type___BinaryDeviceIsBusyResponse = BinaryDeviceIsBusyResponse

class BinaryDeviceDetectRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    identify_devices: builtin___bool = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        identify_devices : typing___Optional[builtin___bool] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"identify_devices",b"identify_devices",u"interface_id",b"interface_id"]) -> None: ...
type___BinaryDeviceDetectRequest = BinaryDeviceDetectRequest

class BinaryDeviceDetectResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    devices: google___protobuf___internal___containers___RepeatedScalarFieldContainer[builtin___int] = ...

    def __init__(self,
        *,
        devices : typing___Optional[typing___Iterable[builtin___int]] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"devices",b"devices"]) -> None: ...
type___BinaryDeviceDetectResponse = BinaryDeviceDetectResponse

class BinaryDeviceGetSettingRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    setting: builtin___int = ...
    unit: typing___Text = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        setting : typing___Optional[builtin___int] = None,
        unit : typing___Optional[typing___Text] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device",b"device",u"interface_id",b"interface_id",u"setting",b"setting",u"unit",b"unit"]) -> None: ...
type___BinaryDeviceGetSettingRequest = BinaryDeviceGetSettingRequest

class BinaryDeviceGetSettingResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    value: builtin___float = ...

    def __init__(self,
        *,
        value : typing___Optional[builtin___float] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"value",b"value"]) -> None: ...
type___BinaryDeviceGetSettingResponse = BinaryDeviceGetSettingResponse

class BinaryDeviceSetSettingRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...
    setting: builtin___int = ...
    value: builtin___float = ...
    unit: typing___Text = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        setting : typing___Optional[builtin___int] = None,
        value : typing___Optional[builtin___float] = None,
        unit : typing___Optional[typing___Text] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device",b"device",u"interface_id",b"interface_id",u"setting",b"setting",u"unit",b"unit",u"value",b"value"]) -> None: ...
type___BinaryDeviceSetSettingRequest = BinaryDeviceSetSettingRequest

class BinaryDeviceParkRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    interface_id: builtin___int = ...
    device: builtin___int = ...

    def __init__(self,
        *,
        interface_id : typing___Optional[builtin___int] = None,
        device : typing___Optional[builtin___int] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"device",b"device",u"interface_id",b"interface_id"]) -> None: ...
type___BinaryDeviceParkRequest = BinaryDeviceParkRequest

class BinaryDeviceParkResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    is_parked: builtin___bool = ...

    def __init__(self,
        *,
        is_parked : typing___Optional[builtin___bool] = None,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"is_parked",b"is_parked"]) -> None: ...
type___BinaryDeviceParkResponse = BinaryDeviceParkResponse



# ===== THIS FILE IS GENERATED FROM A TEMPLATE ===== #
# ============== DO NOT EDIT DIRECTLY ============== #

from .motion_lib_exception import MotionLibException


class IoFailedException(MotionLibException):
    """
    Thrown when the library cannot perform an operation on a file.
    """
